;;;
;;; The (do-simulation) function below sets up parameter values, the
;;; number of simulation to be carried out, and the how the parameter
;;; values will be changed over the simlaitions.
;;;
;;; For example, (do-simulation '(0.91 2 0.67 0) '(2 1 3 1) '(0.01 0 0.2
;;; 0) :final-run t) sets 1) rho = 0.91, gamma = 2, delta = 0.67, and
;;; sigma = 0 as their initial values, 2) run simulation 6 times (2 x 3)
;;; increasing rho by 0.01 once and delta by 0.2 two times.
;;;
;;; In order to employ multiple agents across groups, say, 21 agents
;;; for group A and 15 agents for group B , you need to set up
;;; *simulation-spec-agent-id* and cand-eval-simulation.sh
;;; accordingly.
;;;


(progn 
  (load "./setup.cl")
  (setf *simulation-spec-agent-id* 
    (gen-alist-agent-ind-group-id (gen-alist-total-num-per-group :num-per-group 1) '(subjid libcon))) 
  (jqp-agent-initialize  
   (parse-integer (sys:command-line-argument 1) :junk-allowed t)
   'libcon "./jqp-voter-model.cl")
  (suppress-output)
  (do-simulation '(0.91 2 0.67 0) '(1 1 1 1) '(0 0 0 0) :final-run t)
  (exit))
