;; -*- mode: common-lisp; package: user -*-


;;;
;;;
;;; Author: Kim, Sung-youn (syounkim@gmail.com)
;;; 
;;; Copyright: All rights are reserved
;;;
;;; This is the 'model file'. It builds delarative and 
;;; procedural knowledge and sets parameter values. 
;;; 
;;;


(in-package #:user)


(clear-all)
(pm-reset)



;;;
;;; DECLARATIVE KNOWLEDGE
;;;


(jqp-make-chunk-type) 
(jqp-add-goal)


;; Creates chunks into memory and sets their positive and negative
;; affect based on data. Stochastic generation is off.

(jqp-build-initial-knowledge-with-noise :sd 0 :group *jqp-group-id*) 


;; Sets initial on-line processing order (k in Eq. (4)) with reference
;; 50 and survey item response rate. 

(jqp-set-initial-ol-order 50 :group *jqp-group-id*) 



;;;
;;; PROCEDURAL KNOWLEDGE
;;;



(P found-new-word
    =goal>
       ISA         comprehend-sentence
       state       nil
    =visual-location>
       ISA         visual-location
    =visual-state>
       ISA         module-state
       modality    free
==>
   -manual>
   =goal>
       state       "attending"
    +visual>
       ISA         visual-object
       screen-pos  =visual-location
)

(P find-next-word
    =goal>
       ISA         comprehend-sentence
       state       "find"
==>
    +visual-location>
       ISA         visual-location
       screen-x    greater-than-current
       nearest     current
    =goal>
       state       "looking"
)

(P attend-word
    =goal>
       ISA         comprehend-sentence
       state       "looking"
    =visual-location>
       ISA         visual-location
    =visual-state>
       ISA         module-state
       modality    free
==>
    =goal>
       state       "attending"
    +visual>
       ISA         visual-object
       screen-pos  =visual-location
)


(P read-word
    =goal>
       ISA         comprehend-sentence
       positive   =p1 
       negative   =n1
       state       "attending"
       word        nil
    =visual>
       ISA         text
       value       =word
==>
    -visual-location>
    =goal>
       word        =word
       state       "read" 
    +retrieval>
       ISA         meaning
       positive    =p1
       negative    =n1
       word        =word
)


(P skip-a
    =goal>
       ISA         comprehend-sentence
       word        "a"
       state       "read"
==>
    =goal>
       state       "find"
       word        nil
   )

(P skip-an
    =goal>
       ISA         comprehend-sentence
       word        "an"
       state       "read"
==>
    =goal>
       state       "find"
       word        nil
   )

(P skip-the
    =goal>
       ISA         comprehend-sentence
       word        "the"
       state       "read"
==>
    =goal>
       state       "find"
       word        nil
   )


(P skip-says
    =goal>
       ISA         comprehend-sentence
       word        "says"
       state       "read"
==>
    =goal>
       state       "find"
       word        nil
   )

(P skip-for
    =goal>
       ISA         comprehend-sentence
       word        "for"
       state       "read"
==>
    =goal>
       state       "find"
       word        nil
   )

(P skip-asks
    =goal>
       ISA         comprehend-sentence
       word        "asks"
       state       "read"
==>
    =goal>
       state       "find"
       word        nil
   )


;;
;; Reading and Processing Sentences
;;


(P process-first-noun-survey
    =goal>
       ISA         comprehend-sentence
       source       nil
       word        =word
       state       "read"
    =retrieval>
       ISA         meaning
       positive    =p1 
       negative    =n1
       word        "survey"           
==>
    =goal>
       source      (!eval! (+ =p1 =n1)) 
       word        nil     
       purpose     "survey"
       state       "find"
)

(P process-first-noun
    =goal>
       ISA         comprehend-sentence
       source       nil
       word        =word
       state       "read"
    =retrieval>
       ISA         meaning
       positive    =p1 
       negative    =n1
       word        =word           
==>
    =goal>
       source      (!eval! (+ =p1 =n1))
       word        nil       
       state       "find"
)

(P process-second-noun
    =goal>
       ISA         comprehend-sentence       
       agent       nil
       source      =source
       word        =word
       state       "read"
    =retrieval>
       ISA         meaning
       positive    =p1 
       negative    =n1
       word        =word           
==>
    =goal>
       agent       =retrieval
       positive    =p1 
       negative    =n1
       word        nil
       state       "find"
)


(P process-verb-oppose
    =goal>
       ISA         comprehend-sentence
       agent       =val
       action      nil
       source      =source
       word        "opposes"
       state       "read"
    =retrieval>
       ISA         meaning
       word        "opposes"
==>
    =goal>
       action      =retrieval
       word        nil
       state       "find"
       purpose     "study-negative-association"
)


(P process-verb
    =goal>
       ISA         comprehend-sentence
       agent       =agent
       action      nil
       object      nil
       source      =source
       word        =word
       state       "read"
    =retrieval>
       ISA         meaning
       word        =word
==>
    =goal>
       action      =retrieval 
       word        nil
       state       "find"
)


(P process-last-noun-attitude-report
    =goal>
       ISA         comprehend-sentence
       positive    =pos
       negative    =neg
       positive1   0
       negative1   0
       agent       what-do-you
       action      think-about 
       object      nil
       source      =source
       word        =word
       purpose     "survey"
       state       "read"
    =retrieval>
       ISA         meaning
       positive    =p1 
       negative    =n1
       word        =word                  
==>
   =goal>
       positive    0
       negative    0
       positive1   0
       negative1   0
       agent       nil
       action      nil
       object      nil
       source      nil
       word        nil
       purpose     nil
       state       nil 
    +goal>
       ISA         report-attitude
       positive    =pos
       negative    =neg
       object      =retrieval 
       word        =word
       state       "report-attitude-retrieval"
)


(P process-last-noun
    =goal>
       ISA         comprehend-sentence
       positive    =pos
       negative    =neg
       positive1   0
       negative1   0
       agent       =agent
       action      =action
       object      nil
       source      =source
       word        =word
       purpose     "study-sentence"
       state       "read"
    =retrieval>
       ISA         meaning
       positive    =p1 
       negative    =n1
       word        =word                  
==>
    =goal>
       positive1   =p1
       negative1   =n1
       object      =retrieval
       state       "last-object-evaluation-start"
)

(P process-last-noun-negative-association
    =goal>
       ISA         comprehend-sentence
       positive    =pos
       negative    =neg
       positive1   0
       negative1   0
       agent       =agent
       action      =action
       object      nil
       source      =source
       word        =word
       purpose     "study-negative-association"
       state       "read"
    =retrieval>
       ISA         meaning
       positive    =p1 
       negative    =n1
       word        =word                  
==>
    =goal>
       positive1   =p1
       negative1   =n1
       object      (!eval! (progn (jqp-increase-wme-references (jqp-get-safe-anti-wme =retrieval))
				  (jqp-get-safe-anti-wme =retrieval))) 
       word        (!eval! (get-safe-slot-value (jqp-get-safe-anti-wme =retrieval) 'word))
       purpose     "study-sentence"
       state       "last-object-evaluation-start"
)


;;
;; Constructed Implication of Information
;;


(P process-last-word-object-evaluation-start
    =goal>
       ISA         comprehend-sentence
       positive    =pos1
       negative    =neg1
       positive1   =pos2
       negative1   =neg2
       agent       =agent
       action      =action
       object      =object
       source      =source
       word        =word
       state       "last-object-evaluation-start"
==>
    +retrieval>
       ISA         meaning
       positive    (!eval! (list =pos1 =pos2)) 
       negative    (!eval! (list =neg1 =neg2)) 
       word        =word                  
    =goal>
       state       "last-object-evaluation"
)


(P process-last-word-object-evaluation
    =goal>
       ISA         comprehend-sentence
       positive    =pos
       negative    =neg
       agent       =agent
       action      =action
       object      =object
       source      =source
       word        =word
       state       "last-object-evaluation"
    =retrieval>
       ISA         meaning
       positive    =p1 
       negative    =n1
       word        =word                  
==>
    =goal>
       positive1   (!eval! (jqp-pos-attitude-colorization-fct (list =retrieval =agent))) 
       negative1   (!eval! (jqp-neg-attitude-colorization-fct (list =retrieval =agent)))
       source       nil 
       state       "sentence-complete"
       !eval!      (jqp-increase-considerations-on-spot-references (list =retrieval =agent)) 
)


;;
;; Constructed Evaluation of an Object
;;

(P  report-attitude-retrieval
    =goal>
       ISA         report-attitude
       positive    =pos
       negative    =neg
       object      =object
       word        =word
       state       "report-attitude-retrieval"
==>
    +retrieval>
       ISA         meaning
       positive    =pos
       negative    =neg
       word        =word
    =goal>
       state       "report-attitude"
)


(P  report-attitude
    =goal>
       ISA         report-attitude
       state       "report-attitude"
    =retrieval>
       ISA         meaning
       positive    =pos
       negative    =neg
==>
    !eval!         (jqp-record-survey-response-evaluation (list =retrieval)) 
    !eval!         (jqp-increase-considerations-on-spot-references (list =retrieval)) 
    -visual>
    =goal>
       agent       nil
       object      nil
    +goal>
       ISA         comprehend-sentence
       positive    0
       negative    0
       positive1   0
       negative1   0
       agent       nil
       action      nil
       object      nil
       source      nil
       warning     nil
       purpose     "study-sentence"
       word        nil
       state       nil  
)


;;
;; Online Processing 
;; 


(P  online-processing-begin
    =goal>
       ISA         comprehend-sentence
       agent       =agent
       action      =action
       object      =object   
       state       "sentence-complete"
==>
    =goal>
       ISA         comprehend-sentence
       agent       =agent
       action      =action
       object      =object   
       state       "online-updating-proceed" 
    +retrieval>    =agent      
)

(P  candidate-online-updating
    =goal>
       ISA         comprehend-sentence
       positive    =positive1
       negative    =negative1
       positive1   =positive2
       negative1   =negative2
       agent       =agent
       action      =action
       object      =object
       purpose     "study-sentence"
       state       "online-updating-proceed"
    =retrieval>
       ISA         meaning
       positive    =positive1
       negative    =negative1
==>
    =retrieval>
       ISA         meaning
       positive    (!eval! (online-updating =retrieval =positive1 =positive2))
       negative    (!eval! (online-updating =retrieval =negative1 =negative2))
       !eval!      (progn 
		     (add-connection (get-safe-wme 'init-ol-order) (get-safe-wme =retrieval))
		     (add-connection (get-safe-wme =retrieval) (get-safe-wme =object))
		     (add-connection (get-safe-wme =object) (get-safe-wme =retrieval))
		     (reset-ia))
     =goal>
       ISA         comprehend-sentence
       state       "study-sentence-complete" 
    -retrieval>
)


;;
;; Go to Read the Next Sentence
;;


(P study-sentence-read-wait
    =goal>
       ISA         comprehend-sentence
       state       "study-sentence-complete"
==>
    -visual>
    =goal>
       ISA         comprehend-sentence
       positive   0
       negative   0
       positive1   0
       negative1   0
       agent       nil
       action      nil
       object      nil
       source      nil
       warning     nil
       purpose     "study-sentence"
       word        nil
       state       nil  
)


;;;
;;; ACT-R parameters and hoot function 
;;;

(sgp-fct (list :rt 0 :pm t :pas *sigma* :ans *sigma* :bll 0.5)) ;; ACT-R parameters 
(setf *similarity-hook-fn* #'affective-congruence) 


;;;
;;; JQP parameters
;;;

;; Sets parameter values when simulation is carried out by
;; do-simulation. Otherwise directly specify values by numbers

(jqp-set-parameters :rho *rho* :gamma *gamma* :delta *delta* :sigma *sigma*) 



;;;
;;; Baselevel Activation
;;;

(setallbaselevels 1000 -1200) 
(jqp-set-base-level 1000 -1200 :group *jqp-group-id*) 


;;;
;;; etc
;;;

(pm-set-params :show-focus t :real-time nil)
(pm-set-visloc-default :attended new :screen-x lowest)
(reset-ia)

(setf *actr-enabled-p* t)
(goal-focus goal)

