;; -*- mode: common-lisp; package: user -*-


;;;
;;;
;;; Author: Kim, Sung-youn (syounkim@gmail.com)
;;; 
;;; Copyright: All rights are reserved
;;;
;;; This file defines basic setup for the model, which includes the
;;; data used to build knowledge structure and the campaign statments
;;; to be processed. 
;;; 
;;;


(in-package #:user)


;;
;; Reading and Processing Information 
;;


(defun study-sentence (text time)
  (let ((text (remove #\- text)))
    (if *actr-enabled-p*
	(study-sentence-model text time)
      (study-sentence-person text time))))


(defun study-sentences (set time &key (in-order t))
  (let ((set (if in-order set (permute-list set))))
    (dolist (x set)    
      (study-sentence x time)
      (reset-ia))))


;;
;; Building Init Knowledge 
;;


(defun jqp-build-initial-knowledge-with-noise (&key group (sd 0) (type 'meaning))
   (jqp-build-initial-knowledge-with-noise-from-alist 
    *initial-admin-knowledge* :sd sd :type type)
   (jqp-build-initial-knowledge-with-noise-from-alist 
    *initial-common-knowledge* :sd sd :type type) 
   (jqp-build-initial-knowledge-with-noise-from-alist 
    *initial-political-knowledge-basic* :sd sd :type type :group group :issue nil)
   (jqp-build-initial-knowledge-with-noise-from-alist 
    *initial-political-knowledge-issue-0* :sd sd :type type :group group :issue t)
   ) 


(defun jqp-set-initial-ol-order (order &key group set-order (scalor 1))
  (jqp-set-initial-ol-order-from-alist 
   *initial-admin-knowledge* order :set-order order) 
  (jqp-set-initial-ol-order-from-alist 
   *initial-common-knowledge* order :set-order order) 
  (jqp-set-initial-ol-order-from-alist 
   *initial-political-knowledge-basic* order :set-order nil :group group :issue nil :scalor scalor) 
  (jqp-set-initial-ol-order-from-alist 
   *initial-political-knowledge-issue-0* order :set-order nil :group group :issue t :scalor scalor)
  )


(defun jqp-set-base-level (base-reference &optional (creation-time nil) &key group (scalor 100))
  (jqp-set-base-level-from-alist *initial-political-knowledge-basic* creation-time 
   :group group :issue nil :base-reference base-reference :scalor scalor)
  (jqp-set-base-level-from-alist *initial-political-knowledge-issue-0* creation-time  
   :group group :issue t :base-reference base-reference :scalor scalor)
  )


;;
;; Simulation Related Functions 
;;


(defun do-experiment (time &key (in-order t) (reset t) mysql-db final-run)
  (study-sentences *survey* time :in-order in-order)
  (study-sentences *campaign-info-set-1* time :in-order in-order)
  (study-sentences *survey* time :in-order in-order)
  (pm-run 100 :full-time t)	
  (study-sentences *campaign-info-set-2* time :in-order in-order)
  (study-sentences *survey* time :in-order in-order)
  (study-sentences *campaign-info-set-motivated-reasoning* time :in-order in-order)
  (study-sentences *survey* time :in-order in-order)
  (when reset
    (progn (jqp-output)
	   (if mysql-db 
	       (progn (when final-run (jqp-voting-print-output :mysql-db mysql-db))
		      (jqp-print-survey-response :mysql-db mysql-db)
		      (jqp-voting-output-add-to-database))
	     (progn (when final-run (jqp-voting-print-output :mysql-db nil))  
		    (jqp-print-survey-response :mysql-db nil))))))  



;;;
;;; Campaign Information
;;;


(defvar *survey*
    '("Survey asks what-do-you think-about James"
      "Survey asks what-do-you think-about Edwards"))

(defvar *campaign-info-set-1*
    '("Edwards says Edwards is a Republican"
      "Edwards says Edwards supports tax-cut"      
      "Edwards says Edwards opposes abortion-rights"      
      "Edwards says Edwards supports school-voucher"
      "Edwards says Edwards supports defense-spending-increase" 

      "Edwards says Edwards opposes partisan-politics"
      "Edwards says Edwards is trustworthy"
      "Edwards says Edwards is sympathetic"
      
      "James says James is a Democrat"
      "James says James opposes tax-cut"
      "James says James supports affirmative-action"      
      "James says James supports abortion-rights"      
      "James says James supports gays-in-military"
     
      "James says James is experienced"				  
      "James says James is trustworthy"
      "James says James is intelligent"))

(defvar *campaign-info-set-2*
    '("Edwards says Edwards is a Republican"
      "James says James is a Democrat"

      "Edwards says Edwards supports tax-cut"
      "Edwards says tax-cut is reasonable"
      "James says James opposes tax-cut"
      "James says tax-cut is risky"

      "Edwards says James is dishonest"
      "James says Edwards is dishonest" 
      "Edwards says James is a squanderer"       
      "James says Edwards is a bumbler"

      "Edwards says Edwards opposes affirmative-action"     
      "James says James opposes school-voucher"
      "Edwards says Edwards opposes gays-in-military"       
      "James says James opposes defense-spending-increase"

      "Edwards says Edwards supports gun-control"
      "James says James supports gun-control"		    
      "Edwards says Edwards supports death-penalty"
      "James says James supports death-penalty"))

(defvar *campaign-info-set-1-wording*
    '("Edwards says Edwards is a Republican"
      "Edwards says Edwards supports tax-cut"      
      "Edwards says Edwards opposes abortion-rights"      
      "Edwards says Edwards supports school-voucher"
      "Edwards says Edwards supports defense-spending-increase" 

      "Edwards says Edwards opposes partisan-politics"
      "Edwards says Edwards is trustworthy"
      "Edwards says Edwards is warm-hearted"
      
      "James says James is a Democrat"
      "James says James opposes tax-cut"
      "James says James supports affirmative-action"      
      "James says James supports abortion-rights"      
      "James says James supports gays-in-military"
     
      "James says James is experienced"				  
      "James says James is trustworthy"
      "James says James is smart"))

(defvar *campaign-info-set-2-order*
    '("Edwards says Edwards is a Republican"
      "James says James is a Democrat"

      "Edwards says James is dishonest"
      "James says Edwards is dishonest"
      "Edwards says James is a squanderer"       
      "James says Edwards is a bumbler"
      
      "Edwards says Edwards opposes affirmative-action"     
      "James says James opposes school-voucher"
      "Edwards says Edwards opposes gays-in-military"       
      "James says James opposes defense-spending-increase"
      
      "Edwards says Edwards supports gun-control"
      "James says James supports gun-control"
      "Edwards says Edwards supports death-penalty"
      "James says James supports death-penalty"
      
      "Edwards says Edwards supports tax-cut"
      "Edwards says tax-cut is reasonable"
      "James says James opposes tax-cut"
      "James says tax-cut is risky"))

(defvar *campaign-info-set-motivated-reasoning*
    '("Edwards says James represents special-interest"
      "James says Edwards represents special-interest"
      "Survey asks what-do-you think-about James"
      "Survey asks what-do-you think-about Edwards"
      "James says James protects public-interest"  
      "Edwards says Edwards protects public-interest"))



;;;;
;;;;
;;;; Initial Knowledge
;;;;
;;;;


;;;
;;; Adminstrative Knowledge 
;;;


(setf *initial-admin-knowledge* 
  '((A 0 0 0 0) (AN 0 0 0 0) (HAS 0 0 0 0) (HELPS 0 0 0 0) 
    (INVOLVED 0 0 0 0) (IS-INVOLVED 0 0 0 0) (IS 0 0 0 0) 
    (ARE 0 0 0 0) (OPPOSES 0 0 0 0) (OPPOSE 0 0 0 0) 
    (PREFERS 0 0 0 0)  (REPRESENTS 0 0 0 0) (SUPPORTS 0 0 0 0) (SUPPORT 0 0 0 0) 
    (THE 0 0 0 0) (BY 0 0 0 0) (EXPANDS 0 0 0 0) (MAKE 0 0 0 0) 
    (SAYS 0 0 0 0) (SAID 0 0 0 0) (ASKS 0 0 0 0) (UPHOLD 0 0 0 0) 
    (THINK-ABOUT 0 0 0 0) (WHAT-DO-YOU 0 0 0 0) (for 0 0 0 0) (means 0 0 0 0)
    (PROTECTS 0 0 0 0) (SURVEY 0 0 0 0) (NEWS 0 0 0 0) (BASED-ON 0 0 0 0) 
    (fights 0 0 0 0) (init-ol-order 0 0 0 0)))



;;;
;;; Common Knowledge (social concepts, traits, ...).  
;;;
;;; This comes from ANEW and N. Anderson (1976)
;;;


(setf *initial-common-knowledge*
  '(
    (CARING 0.68 0 0.103 0)	
    (ETHICAL 0.67 0 0.14 0)		
    (SMART 0.63 0 0.22 0)	
    (WARM-HEARTED 0.68 0 0.103 0)		
    (SYMPATHETIC 0.53 0 0.55 0)		
    (DISHONEST 0 -0.86 0 0.085)	
    (EXPERIENCED 0.503 0 0.126 0)	
    (HONEST 0.85 0 0.078 0)	
    (INSPIRING 0.43 0 0.106 0)		
    (INSINCERE 0 -0.78 0 0.10)	
    (KNOWLEDGEABLE 0.626 0 0.108 0)	
    (INTELLIGENT 0.79 0 0.21 0)		
    (INTELLECTUAL 0.59 0 0.3 0)	
    (SQUANDERER 0 -0.46 0 0.111)
    (TRUSTWORTHY 0.79 0 0.10 0)	
    (SPECIAL-INTEREST 0 -0.695 0 0.168)	
    (PUBLIC-INTEREST 0.695 0 0.168 0)	
    (PARTISAN-POLITICS 0 -0.73 0 0.09)	
    (ANTI-PARTISAN-POLITICS 0.73 0 0.09 0)
    (REASONABLE 0.676 0 0.143 0)	
    (BUMBLER 0 -0.626 0 0.108)		
    (RISKY 0 -0.512 0 0.2775)		
    (NASTY 0 -0.35500002 0 0.2975)	 
    (OPEN-MINDED 0.76 0 0.093 0)
    (CAPABLE 0.57 0 0.105 0)	       
    (SPIRITED 0.59 0 0.106 0)	       
    (FREEDOM 0.645 0 0.255 0)	
    (PROGRESSIVE 0.56 0 0.13 0)	
    (UNWISE 0 -0.4 0 0.13)
    (JUSTICE 0.695 0 0.168 0)
    (NARROW-MINDED 0 -0.73 0 0.096)
    ))


;;;
;;;
;;; Political Knowledge
;;;
;;; From ANES 2000 and NES 2000 Survey
;;;


(setf *initial-political-knowledge-basic* 
    '((STRONG-LIBERAL 
       (DEMOCRAT 0.7152047 -0.4864865 0.3083534 0.3475274 0.8099762) 
       (REPUBLICAN 0.4864865 -0.7152047 0.3475274 0.3083534 0.8099762)
       )
      (LIBERAL 
       (DEMOCRAT 0.68 -0.50 0.30 0.31 0.867) 
       (REPUBLICAN 0.50 -0.68 0.31 0.30 0.867)
       )
      (MODERATE 
       (DEMOCRAT 0.621 -0.547 0.312 0.302 0.868) 
       (REPUBLICAN 0.547 -0.621 0.302 0.312 0.868)
       )
      (CONSERVATIVE 
       (DEMOCRAT 0.6467505 -0.7135562 0.3165840 0.2950508 0.8779661)
       (REPUBLICAN 0.7135562 -0.6467505 0.2950508 0.3165840 0.8779661)
       )
      (STRONG-CONSERVATIVE 
       (DEMOCRAT 0.6896135 -0.8096798 0.3444756 0.2840396 0.8720760)
       (REPUBLICAN 0.8096798 -0.6896135 0.2840396 0.3444756 0.8720760)
       )))


(setf *initial-political-knowledge-issue-0*
    '((STRONG-LIBERAL 
       (JAMES 0 0 0 0 0)  ;; fictitious candidate
       (EDWARDS 0 0 0 0 0) ;; fictitious candidate
       (SCHOOL-VOUCHER 0.366 -0.633 0.48 0.48 0.97) 
       (ABORTION-RIGHTS 0.829 -0.17 0.37 0.37 0.96)  
       (DEATH-PENALTY 0.54 -0.45 0.49 0.49 0.53) 
       (GAYS-IN-MILITARY 0.77 -0.22 0.41 0.41 0.536) 
       (AFFIRMATIVE-ACTION 0.69 -0.30 0.46 0.46 0.363)
       (MEDICAID 0.873 -0.312 0.333 0.468 0.365)
       (GUN-CONTROL 0.958 -0.825 0.200 0.381 0.984)
       (DEFENSE-SPENDING-INCREASE 0.555 -0.621 0.497 0.485 0.982)
       (TAX-CUT 0.343 -0.656 0.475 0.475 0.429)
       (SMALL-GOVERNMENT 0.612 -0.780 0.48 0.41 0.876)       
       )
      (LIBERAL 
       (JAMES 0 0 0 0 0)  ;; fictitious candidate
       (EDWARDS 0 0 0 0 0) ;; fictitious candidate
       (SCHOOL-VOUCHER 0.362 -0.633 0.48 0.48 0.96)  
       (ABORTION-RIGHTS 0.81 -0.18 0.38 0.38 0.96) 
       (DEATH-PENALTY 0.67 -0.32 0.46 0.46 0.52) 
       (GAYS-IN-MILITARY 0.77 -0.22 0.41 0.41 0.5)
       (AFFIRMATIVE-ACTION 0.63 -0.36 0.48 0.48 0.36)
       (MEDICAID 0.82 -0.21 0.37 0.41 0.36)
       (GUN-CONTROL 0.93 -0.69 0.24 0.46 0.98)
       (DEFENSE-SPENDING-INCREASE 0.51 -0.40 0.49 0.49 0.98)
       (TAX-CUT 0.343 -0.656 0.475 0.475 0.429)
       (SMALL-GOVERNMENT 0.612 -0.780 0.48 0.41 0.876) 
       )
      (MODERATE 
       (JAMES 0 0 0 0 0)  ;; fictitious candidate
       (EDWARDS 0 0 0 0 0) ;; fictitious candidate
       (SCHOOL-VOUCHER 0.413 -0.586 0.492 0.492 0.958)  
       (ABORTION-RIGHTS 0.722 -0.277 0.447 0.447 0.944)      
       (DEATH-PENALTY 0.757 -0.242 0.428 0.428 0.517) 
       (GAYS-IN-MILITARY 0.654 -0.345 0.475 0.475 0.486)
       (AFFIRMATIVE-ACTION 0.512 -0.487 0.499 0.499 0.357)
       (MEDICAID 0.744 -0.225 0.435 0.418 0.366) 
       (GUN-CONTROL 0.910 -0.674 0.285 0.468 0.986)
       (DEFENSE-SPENDING-INCREASE 0.621 -0.290 0.485 0.454 0.986) 
       (TAX-CUT 0.57 -0.42 0.498 0.498 0.385)
       (SMALL-GOVERNMENT 0.55 -0.63 0.501 0.484 0.816)       
       )      
      (CONSERVATIVE 
       (JAMES 0 0 0 0 0)  ;; fictitious candidate
       (EDWARDS 0 0 0 0 0) ;; fictitious candidate
       (SCHOOL-VOUCHER 0.535 -0.464 0.498 0.498 0.957)   
       (ABORTION-RIGHTS 0.517 -0.482 0.499 0.499 0.935)
       (DEATH-PENALTY 0.811 -0.188 0.391 0.391 0.527) 
       (GAYS-IN-MILITARY 0.452 -0.547 0.497 0.497 0.495)
       (AFFIRMATIVE-ACTION 0.411 -0.588 0.492 0.492 0.335)
       (MEDICAID 0.687 -0.314 0.463 0.464 0.343) 
       (GUN-CONTROL 0.866 -0.742 0.340 0.437 0.983) 
       (DEFENSE-SPENDING-INCREASE 0.754 -0.254 0.430 0.435 0.985)
       (TAX-CUT 0.723 -0.277 0.44 0.44 0.461) 
       (SMALL-GOVERNMENT 0.771 -0.588 0.42 0.492 0.867)
       )
      (STRONG-CONSERVATIVE 
       (JAMES 0 0 0 0 0)  ;; fictitious candidate
       (EDWARDS 0 0 0 0 0) ;; fictitious candidate
       (SCHOOL-VOUCHER 0.657 -0.342 0.474 0.474 0.964)  
       (ABORTION-RIGHTS 0.359 -0.640 0.480 0.480 0.952) 
       (DEATH-PENALTY 0.826 -0.173 0.378 0.378 0.519) 
       (GAYS-IN-MILITARY 0.274 -0.725 0.446 0.446 0.498) 
       (AFFIRMATIVE-ACTION 0.373 -0.626 0.484 0.484 0.340)
       (MEDICAID 0.664 -0.494 0.473 0.501 0.341) 
       (GUN-CONTROL 0.851 -0.823 0.355 0.381 0.979) 
       (DEFENSE-SPENDING-INCREASE 0.850 -0.368 0.357 0.483 0.983)
       (TAX-CUT 0.723 -0.277 0.44 0.44 0.461) 
       (SMALL-GOVERNMENT 0.771 -0.588 0.42 0.492 0.867))))


(setf *chunks-to-check* 
  '(james edwards republican democrat tax-cut abortion-rights bumbler trustworthy))

